<!--

Please note that by submitting a PR with a new proposal, you agree to release this proposal text under the Creative Commons Zero v1.0 Universal license. See https://github.com/PlaintextGroup/oss-virtual-incubator/blob/main/LICENSE.

If you'd like to submit a proposal yourself, you have two options:

1. Fork this repo and make a copy of [PROPOSAL-TEMPLATE.md](PROPOSAL-TEMPLATE.md). Write up your proposal in the `proposals` directory, then [make a pull request](https://github.com/PlaintextGroup/oss-virtual-incubator/pulls) to this repository.
2. If you'd rather just use a form, [fill out this form][form]. Unless you tell us otherwise, we will copy over your proposal to this GitHub repository.

-->

### Title

DAOVOTION: A Decentralized Business Model for Open Source Development based on Web3 principles.

### Short description

**DAOVOTION** is the proposed solution for helping OSS developers building a business organization for sustaining Intellectual Goods: the Egregore. This organization ensures a continuous quality assurance for OSS and Public Domain productions, and at the same time encourages investors on nurturing the intellectual production financially, while getting a valuable collateral that represents a good measure for **Reputation**, as it is required for building robust DeFi projects.

### Author(s)

[@nebairevelations](https://github.com/nebairevelations), [@superoptimo](https://github.com/superoptimo)



### Proposal body

A proper solution for FOSS projects should consist of structuring an organization around the development of the software, which facilitates the exchange of ideas and encourages collaboration for the community members committed to the betterment of the software.

That kind of organization is what [DAOVOTION](https://nebairevelations.com/) features with the [Egregore](https://nebairevelations.com/glossary/#egregore) concept. The principle of the **Egregore** as a business organization consists of manifesting the value of communal ownership around the maintenance of Open Source software, or any [Intellectual Work](https://nebairevelations.com/glossary/#intellectual-goods) in general.

An [Egregore](https://nebairevelations.com/glossary/#egregore) is Decentralized Autonomous Organization (DAO), focused on collecting funds for sustaining the development of a particular [Intellectual Goods](https://nebairevelations.com/glossary/#intellectual-goods) Project, which in most cases could be an Open Source Software project. The most fundamental aspect of an **Egregore** is that it represents the consolidated will of a group of individuals towards a common goal. Members of an **Egregore** look after the project’s well-being and manifest a sense of belonging for the commonly shared patrimony, as the Egregore offers support and welfare to its members in compensation.

A carefully designed [Tokenomics](https://nebairevelations.com/daovotion/) is key for granting a FOSS project the ability to offer value to its investors. **DAOVOTION** establishes a set of rules to incentivize an accountable behavior for both investors and developers by their association to an Egregore created for supporting a FOSS project.

Investors of an **Egregore** adopt the role of [Devotees](https://nebairevelations.com/glossary/#devotee); those can be considered sponsors with honorable behavior. They look after **Egregores** that represent FOSS projects with a good track of quality and utility offered to its users. The good performance of the project and the honorability of its members is what provides a good [Prestige Score](https://nebairevelations.com/daovotion/#the-prestige-of-an-egregore-8b9dc6df-4547-4647-ae2f-ae399cb91b21) to an **Egregore**.

From that score that represents the reputation of the **Egregore**, **Devotees** obtain the intrinsic value from their investments. This [Prestige Score](https://nebairevelations.com/daovotion/#the-prestige-of-an-egregore-8b9dc6df-4547-4647-ae2f-ae399cb91b21) grants a derived reputation value to a [Devotee Token](https://nebairevelations.com/glossary/#devotee-token), which is considered a collateral asset that can be staked in services that require insurance. For example in DeFi applications, a **Devotee Token** can be staked as collateral for lending. Another use case could be securing Oracles that provide accurate reporting in Prediction Markets applications, which means that Devotees could earn money by staking their tokens for information assurance services.

**Egregores** perform as **Insurance Institutions** for supporting DeFi loans, not only by staking their **Prestige**, but also for maintaining an [Insurance Vault](https://nebairevelations.com/glossary/#insurance-vault) for repaying owed obligations to Lenders or demanding parties that were affected by the non-fulfillment of the obligations contracted by **Devotees**, such a defaulted loan or failing to secure a network when they’re using their **Devotee Tokens** as collateral.

Also by possessing a **Devotee Token**, investors are entitled to sell new Devotee Tokens to interested clients that want to become members of the Egregore. In that way, Devotees act as brand ambassadors and sales agents for the Egregore, while providing funds for supporting the labor of developers in a FOSS project. From this activity, as Devotees recruit new members into the organization they'll earn commissions from each token sale.

For testing the truth about the health of the FOSS projects, **DAOVOTION** establishes a system for evaluating the efforts in maintaining a good quality track. With [Arbitration Trials](https://nebairevelations.com/daovotion/#arbitration-trials-and-the-quest-for-truth-6bb9bdb3-3dc9-4c63-a137-784de8b34667), Devotees from other projects could act as **Jurors** and deliberate against a particular **Egregore**. Its **Prestige Score** is affected when **Jurors** evaluate how good or bad are its developers maintaining the quality of the project, and how they're responding to the demands of its users.

From these trials, developers feel the pressure for providing good quality content and pursuing excellence in their efforts, and **Devotees** become aware of the value appreciation from their investments in the project. **Arbitration Trials** motivates **Authors** (developers) and **Devotees** (investors) in working consistently on improving the quality of their productions. Also, they’d be willing to invest more money and effort in correcting issues that affect the user’s experience.

Because the historical performance of the **Egregore's Prestige Score** is tracked in the blockchain, any interested party could analyze how Authors (developers) are committed to the fulfillment of the community expectations about their **Intellectual Goods** development, but also shows the degree of shared responsibility that Devotees perform when honoring their contractual obligations from DeFi applications.

In that way, [DAOVOTION Tokenomics](https://nebairevelations.com/daovotion/) stimulates a healthy competence between Egregores, nurturing a dynamic market where **Authors** and **Devotees** join forces in maintaining a good reputation for their Egregores and pursuing excellence in their quality efforts, just for offering the best possible value to its users. Egregore members are encouraged to think ahead and make the right decisions for their projects, as they're aware that those Egregores with higher Prestige Score are more attractive to potential investors that are just looking for good quality collateral.

### Due diligence

<!-- Please answer the following due diligence questions; it's okay to answer "N/A" if you don't know yet. -->

1. **What related work has already been done in this area?**

For decades, OSS have already being sustained by philanthropic funding mostly, but this non-profit approach rarely could effectively sustain consistent efforts in quality assurance, as there aren’t any economical incentives for investors.

Just recently, **Gitcoin Grants** program were launched with the sole purpose of supporting Public Goods and OSS projects. But as this solution is married with the Quadratic Voting paradigm,  it not just only failed to sustain independent OSS projects (because the QF formula ended up leaving the majority of the projects underfunded by removing the donations from small projects for then funneling those funds into the most popular projects, as [reported here](https://discord.com/channels/562828676480237578/783772122992476231/918312987167699024)).

Also QF brought more security issues because this funding model gives perverse incentives to attackers that could steal funds by manipulating the voting system with fake projects. (The Gitcoin community [has already aware of this problem](https://medium.com/block-science/deterring-adversarial-behavior-at-scale-in-gitcoin-grants-a8a5cd7899ff), acknowledging that the Quadratic Voting model is vulnerable to **"Sybil Attacks"** and **collusion** by coordinated voting. Preventing fraud in QF is currently the most demanded issue in Gitcoin foundation, but right now there isn't a feasible solution for that because detecting adversarial behavior requires exotic Machine Learning technologies that the IT world hasn't had yet).

Another approach that is very close to the solution proposed in this document, is [Quine’s GitNFT](https://gitnft.quine.sh/), which concedes digital property based on the commits published in Git platform repositories (initially at GitHub). Developers create NFTs of their commits on GitHub. To do this, users prove authorship of a commit via GitHub OAuth and cryptographically sign the commit with their Ethereum wallet. However, as it is still in early stages, have been suffering from impersonation attacks or false contributors as [denounced here](https://medium.com/quine/the-1st-commit-of-git-git-no-longer-belongs-to-linus-torvalds-ea1df6f8f025). In the long run, **GitNFT** would suffer from the market-driven speculation that affects most NFT collections that cannot handle another intrinsic value but just the expectation for future valuation in their resales.

Our conclusion is that NFT technology should be linked to an application layer that at least manages contextual information about the performance of the asset based on its utility. That aspect is what **DAOVOTION** offers in its value proposition.

2. **How is this proposal innovative -- what distinguishes it from other related work?** DAOVOTION proposal consists of building **Value Capturing** on the organization that develops the OSS, rather than tokenizing just the digital content (as GitNFT does). As we recognize that OSS cannot be owned and collected as digital commodities, but instead being valuated as a service, **DAOVOTION** features its economical value from the Organization Prestige. This converts the community around the development of the OSS into a **Insurance Institution** that serves as collateral provider for investors that want to deal with DeFi applications.

3. **Who is your doer -- who will execute the proposed work?** [Nebai Leon](https://www.linkedin.com/in/nebaileon1994/) is performing as the director of this project, designing the business model of the application. Also, Francisco Leon ([@superoptimo](https://github.com/superoptimo)) is working as the main software developer in this project, programming the server backend infrastructure and the smart-contract business logic.
In the near future, we will recruit new members in our team, talented individuals that could help with the communication strategies of these ideas, and software developers. Also we're looking for strategic business partners that could help this project grow.
 
4. **How might this work be sustained long-term after an initial seed grant?** As a blockchain project, **DAOVOTION** is designed for sustained itself with the conformation of a [Governance Board](https://nebairevelations.com/governance/). Interested partners would being able to obtain participation power in this governance by acquiring NFTs from the [Nebai Revelations' Art Collection](https://opensea.io/collection/nebai-revelations/) and playing the [Treasure Hunting Game](https://nebairevelations.com/governance/#nebai-revelations-treasury-hunting-game).

### Resources needed

<!-- What resources are needed (grant money, advisors, expertise, etc.) to realize this proposal? -->
At first, for realizing this project we need team members that help to build a learning community. We would need advisors, expertise, journalists and influencers that help with the communication of ideas and educating the public about how this idea benefits to society. 
At the same time, we need software developers and security experts that help with the construction of the DApp.

### Other links and resources

<!-- Add any other links, images, or resources that are relevant to the proposal -->
Please visit our website [NebaiRevelations.com](https://nebairevelations.com). Also read our article that explains the problematic of funding FOSS at [substack](https://nebairevelations.substack.com/p/a-successful-business-model-for-open).
